@@ -46,18 +46,16 @@ setMethod("dcemri.bayes", signature(conc="array"),
                          ab.tauepsilon=c(1,1/1000), samples=FALSE,
                          multicore=FALSE, verbose=FALSE, dic=FALSE, ...)
           .dcemriWrapper("dcemri.bayes", conc, time, img.mask, model,
-                         aif, user, nriters, thin,
-                         burnin, tune, ab.ktrans,
-                         ab.kep, ab.vp,
-                         ab.tauepsilon, samples,
-                         multicore, verbose, dic, ...))
+                        aif, user, nriters, thin, burnin, tune, ab.ktrans,
+                        ab.kep, ab.vp, ab.tauepsilon, samples,
+                        multicore, verbose, dic, ...))
 
 .dcemri.bayes.single <- function(conc, time, nriters=3500, thin=3,
-                                burnin=500, tune=267, ab.gamma=c(0,1),
-                                ab.theta=c(0,1), ab.vp=c(1,19),
-                                ab.tauepsilon=c(1,1/1000), aif.model=0,
-                                aif.parameter=c(2.4,0.62,3,0.016), vp=1) {
-
+                                 burnin=500, tune=267, ab.gamma=c(0,1),
+                                 ab.theta=c(0,1), ab.vp=c(1,19),
+                                 ab.tauepsilon=c(1,1/1000), aif.model=0,
+                                 aif.parameter=c(2.4,0.62,3,0.016), vp=1) {
+  
   if (sum(is.na(conc)) > 0) {
     return(NA)
   } else {
@@ -413,5 +411,4 @@ setMethod("dcemri.bayes", signature(conc="array"),
   
   return(returnable)
 }
-  
-  
+
